# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2payoutsMerchantInformationMerchantDescriptor(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'locality': 'str',
        'country': 'str',
        'administrative_area': 'str',
        'postal_code': 'str',
        'contact': 'str'
    }

    attribute_map = {
        'name': 'name',
        'locality': 'locality',
        'country': 'country',
        'administrative_area': 'administrativeArea',
        'postal_code': 'postalCode',
        'contact': 'contact'
    }

    def __init__(self, name=None, locality=None, country=None, administrative_area=None, postal_code=None, contact=None):
        """
        Ptsv2payoutsMerchantInformationMerchantDescriptor - a model defined in Swagger
        """

        self._name = None
        self._locality = None
        self._country = None
        self._administrative_area = None
        self._postal_code = None
        self._contact = None

        if name is not None:
          self.name = name
        if locality is not None:
          self.locality = locality
        if country is not None:
          self.country = country
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if postal_code is not None:
          self.postal_code = postal_code
        if contact is not None:
          self.contact = contact

    @property
    def name(self):
        """
        Gets the name of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Your merchant name.  **Note** For Paymentech processor using Cybersource Payouts, the maximum data length is 22.  #### PIN debit Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests.  #### Airline processing Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  **Note** Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field.  **Important** This value must consist of English characters.  Required for captures and credits. 

        :return: The name of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Your merchant name.  **Note** For Paymentech processor using Cybersource Payouts, the maximum data length is 22.  #### PIN debit Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests.  #### Airline processing Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  **Note** Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field.  **Important** This value must consist of English characters.  Required for captures and credits. 

        :param name: The name of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :type: str
        """

        self._name = name

    @property
    def locality(self):
        """
        Gets the locality of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Merchant's City.  #### PIN debit City for your business location. This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests. 

        :return: The locality of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Merchant's City.  #### PIN debit City for your business location. This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests. 

        :param locality: The locality of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if locality is not None and len(locality) > 13:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `13`")

        self._locality = locality

    @property
    def country(self):
        """
        Gets the country of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Merchant's country.  #### PIN debit Country code for your business location. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters. **Note** If your business is located in the U.S. or Canada and you include this field in a request, you must also include `merchantInformation.merchantDescriptor.administrativeArea`.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The country of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Merchant's country.  #### PIN debit Country code for your business location. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters. **Note** If your business is located in the U.S. or Canada and you include this field in a request, you must also include `merchantInformation.merchantDescriptor.administrativeArea`.  Optional field for PIN debit credit or PIN debit purchase. 

        :param country: The country of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :type: str
        """

        self._country = country

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        The state where the merchant is located.  #### PIN debit State code or region code for your business. Use the Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The administrative_area of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        The state where the merchant is located.  #### PIN debit State code or region code for your business. Use the Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada.  Optional field for PIN debit credit or PIN debit purchase. 

        :param administrative_area: The administrative_area of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :type: str
        """

        self._administrative_area = administrative_area

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Merchant's postal code.  #### PIN debit Postal code for your business location. This value might be displayed on the cardholder’s statement.  If your business is domiciled in the U.S., you can use a 5-digit or 9-digit postal code. A 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example: `12345-6789`  If your business is domiciled in Canada, you can use a 6-digit or 9-digit postal code. A 6-digit postal code must follow this format: [alpha][numeric][alpha][space] [numeric][alpha][numeric] Example: `A1B 2C3`  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada. **Important** Mastercard requires a postal code for any country that uses postal codes. You can provide the postal code in your account or you can include this field in your request.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The postal_code of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        Merchant's postal code.  #### PIN debit Postal code for your business location. This value might be displayed on the cardholder’s statement.  If your business is domiciled in the U.S., you can use a 5-digit or 9-digit postal code. A 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example: `12345-6789`  If your business is domiciled in Canada, you can use a 6-digit or 9-digit postal code. A 6-digit postal code must follow this format: [alpha][numeric][alpha][space] [numeric][alpha][numeric] Example: `A1B 2C3`  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada. **Important** Mastercard requires a postal code for any country that uses postal codes. You can provide the postal code in your account or you can include this field in your request.  Optional field for PIN debit credit or PIN debit purchase. 

        :param postal_code: The postal_code of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 14:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `14`")

        self._postal_code = postal_code

    @property
    def contact(self):
        """
        Gets the contact of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        For the descriptions, used-by information, data types, and lengths for these fields, see `merchant_descriptor_contact` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)--> Contact information for the merchant.  **Note** These are the maximum data lengths for the following payment processors: - FDCCompass (13) - Paymentech (13) 

        :return: The contact of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        For the descriptions, used-by information, data types, and lengths for these fields, see `merchant_descriptor_contact` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)--> Contact information for the merchant.  **Note** These are the maximum data lengths for the following payment processors: - FDCCompass (13) - Paymentech (13) 

        :param contact: The contact of this Ptsv2payoutsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if contact is not None and len(contact) > 14:
            raise ValueError("Invalid value for `contact`, length must be less than or equal to `14`")

        self._contact = contact

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2payoutsMerchantInformationMerchantDescriptor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TokenizeParametersCardInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'card_number': 'str',
        'card_expiration_month': 'str',
        'card_expiration_year': 'str',
        'card_type': 'str'
    }

    attribute_map = {
        'card_number': 'cardNumber',
        'card_expiration_month': 'cardExpirationMonth',
        'card_expiration_year': 'cardExpirationYear',
        'card_type': 'cardType'
    }

    def __init__(self, card_number=None, card_expiration_month=None, card_expiration_year=None, card_type=None):
        """
        TokenizeParametersCardInfo - a model defined in Swagger
        """

        self._card_number = None
        self._card_expiration_month = None
        self._card_expiration_year = None
        self._card_type = None

        self.card_number = card_number
        if card_expiration_month is not None:
          self.card_expiration_month = card_expiration_month
        if card_expiration_year is not None:
          self.card_expiration_year = card_expiration_year
        self.card_type = card_type

    @property
    def card_number(self):
        """
        Gets the card_number of this TokenizeParametersCardInfo.
        Encrypted or plain text card number. If the encryption type of “None” was used in the Generate Key request, this value can be set to the plaintext card number/Personal Account Number (PAN). If the encryption type of RsaOaep256 was used in the Generate Key request, this value needs to be the RSA OAEP 256 encrypted card number. The card number should be encrypted on the cardholders’ device. The [WebCrypto API] (https://github.com/CyberSource/cybersource-flex-samples/blob/master/java/spring-boot/src/main/resources/public/flex.js) can be used with the JWK obtained in the Generate Key request.

        :return: The card_number of this TokenizeParametersCardInfo.
        :rtype: str
        """
        return self._card_number

    @card_number.setter
    def card_number(self, card_number):
        """
        Sets the card_number of this TokenizeParametersCardInfo.
        Encrypted or plain text card number. If the encryption type of “None” was used in the Generate Key request, this value can be set to the plaintext card number/Personal Account Number (PAN). If the encryption type of RsaOaep256 was used in the Generate Key request, this value needs to be the RSA OAEP 256 encrypted card number. The card number should be encrypted on the cardholders’ device. The [WebCrypto API] (https://github.com/CyberSource/cybersource-flex-samples/blob/master/java/spring-boot/src/main/resources/public/flex.js) can be used with the JWK obtained in the Generate Key request.

        :param card_number: The card_number of this TokenizeParametersCardInfo.
        :type: str
        """
        if card_number is None:
            raise ValueError("Invalid value for `card_number`, must not be `None`")

        self._card_number = card_number

    @property
    def card_expiration_month(self):
        """
        Gets the card_expiration_month of this TokenizeParametersCardInfo.
        Two digit expiration month

        :return: The card_expiration_month of this TokenizeParametersCardInfo.
        :rtype: str
        """
        return self._card_expiration_month

    @card_expiration_month.setter
    def card_expiration_month(self, card_expiration_month):
        """
        Sets the card_expiration_month of this TokenizeParametersCardInfo.
        Two digit expiration month

        :param card_expiration_month: The card_expiration_month of this TokenizeParametersCardInfo.
        :type: str
        """

        self._card_expiration_month = card_expiration_month

    @property
    def card_expiration_year(self):
        """
        Gets the card_expiration_year of this TokenizeParametersCardInfo.
        Four digit expiration year

        :return: The card_expiration_year of this TokenizeParametersCardInfo.
        :rtype: str
        """
        return self._card_expiration_year

    @card_expiration_year.setter
    def card_expiration_year(self, card_expiration_year):
        """
        Sets the card_expiration_year of this TokenizeParametersCardInfo.
        Four digit expiration year

        :param card_expiration_year: The card_expiration_year of this TokenizeParametersCardInfo.
        :type: str
        """

        self._card_expiration_year = card_expiration_year

    @property
    def card_type(self):
        """
        Gets the card_type of this TokenizeParametersCardInfo.
        Card Type. This field is required. Refer to the CyberSource Credit Card Services documentation for supported card types.

        :return: The card_type of this TokenizeParametersCardInfo.
        :rtype: str
        """
        return self._card_type

    @card_type.setter
    def card_type(self, card_type):
        """
        Sets the card_type of this TokenizeParametersCardInfo.
        Card Type. This field is required. Refer to the CyberSource Credit Card Services documentation for supported card types.

        :param card_type: The card_type of this TokenizeParametersCardInfo.
        :type: str
        """
        if card_type is None:
            raise ValueError("Invalid value for `card_type`, must not be `None`")

        self._card_type = card_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TokenizeParametersCardInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

#import utilities into sdk package
from .flex.token_verification import TokenVerification
from .flex import rsa_verify
from .flex.exception.flex_security_exception import FlexSecurityException


# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .add_negative_list_request import AddNegativeListRequest
from .auth_reversal_request import AuthReversalRequest
from .capture_payment_request import CapturePaymentRequest
from .card_info import CardInfo
from .check_payer_auth_enrollment_request import CheckPayerAuthEnrollmentRequest
from .create_adhoc_report_request import CreateAdhocReportRequest
from .create_bundled_decision_manager_case_request import CreateBundledDecisionManagerCaseRequest
from .create_credit_request import CreateCreditRequest
from .create_invoice_request import CreateInvoiceRequest
from .create_p12_keys_request import CreateP12KeysRequest
from .create_payment_request import CreatePaymentRequest
from .create_report_subscription_request import CreateReportSubscriptionRequest
from .create_search_request import CreateSearchRequest
from .create_shared_secret_keys_request import CreateSharedSecretKeysRequest
from .customer import Customer
from .delete_bulk_p12_keys_request import DeleteBulkP12KeysRequest
from .delete_bulk_symmetric_keys_request import DeleteBulkSymmetricKeysRequest
from .der_public_key import DerPublicKey
from .error import Error
from .error_bean import ErrorBean
from .error_field_bean import ErrorFieldBean
from .error_links import ErrorLinks
from .error_response import ErrorResponse
from .file_bean import FileBean
from .file_detail import FileDetail
from .file_details_response import FileDetailsResponse
from .flex_v1_keys_post200_response import FlexV1KeysPost200Response
from .flex_v1_keys_post200_response_der import FlexV1KeysPost200ResponseDer
from .flex_v1_keys_post200_response_jwk import FlexV1KeysPost200ResponseJwk
from .fraud_marking_action_request import FraudMarkingActionRequest
from .generate_public_key_request import GeneratePublicKeyRequest
from .increment_auth_request import IncrementAuthRequest
from .inline_response_200 import InlineResponse200
from .inline_response_200_1 import InlineResponse2001
from .inline_response_200_1_key_information import InlineResponse2001KeyInformation
from .inline_response_200_2 import InlineResponse2002
from .inline_response_200_2_key_information import InlineResponse2002KeyInformation
from .inline_response_200_3 import InlineResponse2003
from .inline_response_200_3_key_information import InlineResponse2003KeyInformation
from .inline_response_200_key_information import InlineResponse200KeyInformation
from .inline_response_201 import InlineResponse201
from .inline_response_201_1 import InlineResponse2011
from .inline_response_201_1_certificate_information import InlineResponse2011CertificateInformation
from .inline_response_201_1_key_information import InlineResponse2011KeyInformation
from .inline_response_201_error_information import InlineResponse201ErrorInformation
from .inline_response_201_key_information import InlineResponse201KeyInformation
from .inline_response_400 import InlineResponse400
from .inline_response_400_1 import InlineResponse4001
from .inline_response_400_1_fields import InlineResponse4001Fields
from .inline_response_400_2 import InlineResponse4002
from .inline_response_400_details import InlineResponse400Details
from .inline_response_400_errors import InlineResponse400Errors
from .inline_response_default import InlineResponseDefault
from .inline_response_default__links import InlineResponseDefaultLinks
from .inline_response_default__links_next import InlineResponseDefaultLinksNext
from .inline_response_default_response_status import InlineResponseDefaultResponseStatus
from .inline_response_default_response_status_details import InlineResponseDefaultResponseStatusDetails
from .instrument_identifier import InstrumentIdentifier
from .invoice_settings_request import InvoiceSettingsRequest
from .invoicing_v2_invoice_settings_get200_response import InvoicingV2InvoiceSettingsGet200Response
from .invoicing_v2_invoice_settings_get200_response_invoice_settings_information import InvoicingV2InvoiceSettingsGet200ResponseInvoiceSettingsInformation
from .invoicing_v2_invoice_settings_get200_response_invoice_settings_information_header_style import InvoicingV2InvoiceSettingsGet200ResponseInvoiceSettingsInformationHeaderStyle
from .invoicing_v2_invoices_all_get200_response import InvoicingV2InvoicesAllGet200Response
from .invoicing_v2_invoices_all_get200_response_customer_information import InvoicingV2InvoicesAllGet200ResponseCustomerInformation
from .invoicing_v2_invoices_all_get200_response_invoice_information import InvoicingV2InvoicesAllGet200ResponseInvoiceInformation
from .invoicing_v2_invoices_all_get200_response_invoices import InvoicingV2InvoicesAllGet200ResponseInvoices
from .invoicing_v2_invoices_all_get200_response__links import InvoicingV2InvoicesAllGet200ResponseLinks
from .invoicing_v2_invoices_all_get200_response__links_1 import InvoicingV2InvoicesAllGet200ResponseLinks1
from .invoicing_v2_invoices_all_get200_response_order_information import InvoicingV2InvoicesAllGet200ResponseOrderInformation
from .invoicing_v2_invoices_all_get200_response_order_information_amount_details import InvoicingV2InvoicesAllGet200ResponseOrderInformationAmountDetails
from .invoicing_v2_invoices_all_get400_response import InvoicingV2InvoicesAllGet400Response
from .invoicing_v2_invoices_all_get404_response import InvoicingV2InvoicesAllGet404Response
from .invoicing_v2_invoices_all_get502_response import InvoicingV2InvoicesAllGet502Response
from .invoicing_v2_invoices_get200_response import InvoicingV2InvoicesGet200Response
from .invoicing_v2_invoices_get200_response_invoice_history import InvoicingV2InvoicesGet200ResponseInvoiceHistory
from .invoicing_v2_invoices_get200_response_transaction_details import InvoicingV2InvoicesGet200ResponseTransactionDetails
from .invoicing_v2_invoices_post201_response import InvoicingV2InvoicesPost201Response
from .invoicing_v2_invoices_post201_response_invoice_information import InvoicingV2InvoicesPost201ResponseInvoiceInformation
from .invoicing_v2_invoices_post201_response_order_information import InvoicingV2InvoicesPost201ResponseOrderInformation
from .invoicing_v2_invoices_post201_response_order_information_amount_details import InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails
from .invoicing_v2_invoices_post202_response import InvoicingV2InvoicesPost202Response
from .invoicingv2invoices_customer_information import Invoicingv2invoicesCustomerInformation
from .invoicingv2invoices_invoice_information import Invoicingv2invoicesInvoiceInformation
from .invoicingv2invoices_order_information import Invoicingv2invoicesOrderInformation
from .invoicingv2invoices_order_information_amount_details import Invoicingv2invoicesOrderInformationAmountDetails
from .invoicingv2invoices_order_information_amount_details_freight import Invoicingv2invoicesOrderInformationAmountDetailsFreight
from .invoicingv2invoices_order_information_amount_details_tax_details import Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails
from .invoicingv2invoices_order_information_line_items import Invoicingv2invoicesOrderInformationLineItems
from .invoicingv2invoicesid_invoice_information import Invoicingv2invoicesidInvoiceInformation
from .json_web_key import JsonWebKey
from .key_parameters import KeyParameters
from .key_result import KeyResult
from .kmsv2keysasym_key_information import Kmsv2keysasymKeyInformation
from .kmsv2keyssym_client_reference_information import Kmsv2keyssymClientReferenceInformation
from .kmsv2keyssym_key_information import Kmsv2keyssymKeyInformation
from .kmsv2keyssymdeletes_key_information import Kmsv2keyssymdeletesKeyInformation
from .link import Link
from .links import Links
from .mit_reversal_request import MitReversalRequest
from .mit_void_request import MitVoidRequest
from .oct_create_payment_request import OctCreatePaymentRequest
from .patch_customer_payment_instrument_request import PatchCustomerPaymentInstrumentRequest
from .patch_customer_request import PatchCustomerRequest
from .patch_customer_shipping_address_request import PatchCustomerShippingAddressRequest
from .patch_instrument_identifier_request import PatchInstrumentIdentifierRequest
from .patch_payment_instrument_request import PatchPaymentInstrumentRequest
from .payer_auth_setup_request import PayerAuthSetupRequest
from .payment_instrument import PaymentInstrument
from .payment_instrument_list_for_customer import PaymentInstrumentListForCustomer
from .payment_instrument_list_for_customer__embedded import PaymentInstrumentListForCustomerEmbedded
from .payment_instrument_list_for_customer__links import PaymentInstrumentListForCustomerLinks
from .payment_instrument_list_for_customer__links_first import PaymentInstrumentListForCustomerLinksFirst
from .payment_instrument_list_for_customer__links_last import PaymentInstrumentListForCustomerLinksLast
from .payment_instrument_list_for_customer__links_next import PaymentInstrumentListForCustomerLinksNext
from .payment_instrument_list_for_customer__links_prev import PaymentInstrumentListForCustomerLinksPrev
from .payment_instrument_list_for_customer__links_self import PaymentInstrumentListForCustomerLinksSelf
from .payment_instrument_paginated import PaymentInstrumentPaginated
from .post_customer_payment_instrument_request import PostCustomerPaymentInstrumentRequest
from .post_customer_request import PostCustomerRequest
from .post_customer_shipping_address_request import PostCustomerShippingAddressRequest
from .post_instrument_identifier_request import PostInstrumentIdentifierRequest
from .post_payment_instrument_request import PostPaymentInstrumentRequest
from .predefined_subscription_request_bean import PredefinedSubscriptionRequestBean
from .pts_v1_transaction_batches_get200_response import PtsV1TransactionBatchesGet200Response
from .pts_v1_transaction_batches_get200_response__links import PtsV1TransactionBatchesGet200ResponseLinks
from .pts_v1_transaction_batches_get200_response__links_self import PtsV1TransactionBatchesGet200ResponseLinksSelf
from .pts_v1_transaction_batches_get200_response_transaction_batches import PtsV1TransactionBatchesGet200ResponseTransactionBatches
from .pts_v1_transaction_batches_get400_response import PtsV1TransactionBatchesGet400Response
from .pts_v1_transaction_batches_get400_response_error_information import PtsV1TransactionBatchesGet400ResponseErrorInformation
from .pts_v1_transaction_batches_get400_response_error_information_details import PtsV1TransactionBatchesGet400ResponseErrorInformationDetails
from .pts_v1_transaction_batches_get500_response import PtsV1TransactionBatchesGet500Response
from .pts_v1_transaction_batches_get500_response_error_information import PtsV1TransactionBatchesGet500ResponseErrorInformation
from .pts_v1_transaction_batches_id_get200_response import PtsV1TransactionBatchesIdGet200Response
from .pts_v1_transaction_batches_id_get200_response__links import PtsV1TransactionBatchesIdGet200ResponseLinks
from .pts_v1_transaction_batches_id_get200_response__links_transactions import PtsV1TransactionBatchesIdGet200ResponseLinksTransactions
from .pts_v2_credits_post201_response import PtsV2CreditsPost201Response
from .pts_v2_credits_post201_response_credit_amount_details import PtsV2CreditsPost201ResponseCreditAmountDetails
from .pts_v2_credits_post201_response_payment_information import PtsV2CreditsPost201ResponsePaymentInformation
from .pts_v2_credits_post201_response_processing_information import PtsV2CreditsPost201ResponseProcessingInformation
from .pts_v2_credits_post201_response_processing_information_bank_transfer_options import PtsV2CreditsPost201ResponseProcessingInformationBankTransferOptions
from .pts_v2_incremental_authorization_patch201_response import PtsV2IncrementalAuthorizationPatch201Response
from .pts_v2_incremental_authorization_patch201_response_client_reference_information import PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation
from .pts_v2_incremental_authorization_patch201_response_error_information import PtsV2IncrementalAuthorizationPatch201ResponseErrorInformation
from .pts_v2_incremental_authorization_patch201_response__links import PtsV2IncrementalAuthorizationPatch201ResponseLinks
from .pts_v2_incremental_authorization_patch201_response_order_information import PtsV2IncrementalAuthorizationPatch201ResponseOrderInformation
from .pts_v2_incremental_authorization_patch201_response_payment_information import PtsV2IncrementalAuthorizationPatch201ResponsePaymentInformation
from .pts_v2_incremental_authorization_patch201_response_payment_information_account_features import PtsV2IncrementalAuthorizationPatch201ResponsePaymentInformationAccountFeatures
from .pts_v2_incremental_authorization_patch201_response_processor_information import PtsV2IncrementalAuthorizationPatch201ResponseProcessorInformation
from .pts_v2_incremental_authorization_patch400_response import PtsV2IncrementalAuthorizationPatch400Response
from .pts_v2_payments_captures_post201_response import PtsV2PaymentsCapturesPost201Response
from .pts_v2_payments_captures_post201_response__links import PtsV2PaymentsCapturesPost201ResponseLinks
from .pts_v2_payments_captures_post201_response_order_information import PtsV2PaymentsCapturesPost201ResponseOrderInformation
from .pts_v2_payments_captures_post201_response_order_information_amount_details import PtsV2PaymentsCapturesPost201ResponseOrderInformationAmountDetails
from .pts_v2_payments_captures_post201_response_order_information_invoice_details import PtsV2PaymentsCapturesPost201ResponseOrderInformationInvoiceDetails
from .pts_v2_payments_captures_post201_response_point_of_sale_information import PtsV2PaymentsCapturesPost201ResponsePointOfSaleInformation
from .pts_v2_payments_captures_post201_response_processing_information import PtsV2PaymentsCapturesPost201ResponseProcessingInformation
from .pts_v2_payments_captures_post201_response_processor_information import PtsV2PaymentsCapturesPost201ResponseProcessorInformation
from .pts_v2_payments_captures_post400_response import PtsV2PaymentsCapturesPost400Response
from .pts_v2_payments_post201_response import PtsV2PaymentsPost201Response
from .pts_v2_payments_post201_response_client_reference_information import PtsV2PaymentsPost201ResponseClientReferenceInformation
from .pts_v2_payments_post201_response_consumer_authentication_information import PtsV2PaymentsPost201ResponseConsumerAuthenticationInformation
from .pts_v2_payments_post201_response_consumer_authentication_information_ivr import PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr
from .pts_v2_payments_post201_response_error_information import PtsV2PaymentsPost201ResponseErrorInformation
from .pts_v2_payments_post201_response_error_information_details import PtsV2PaymentsPost201ResponseErrorInformationDetails
from .pts_v2_payments_post201_response_installment_information import PtsV2PaymentsPost201ResponseInstallmentInformation
from .pts_v2_payments_post201_response_issuer_information import PtsV2PaymentsPost201ResponseIssuerInformation
from .pts_v2_payments_post201_response__links import PtsV2PaymentsPost201ResponseLinks
from .pts_v2_payments_post201_response__links_self import PtsV2PaymentsPost201ResponseLinksSelf
from .pts_v2_payments_post201_response_order_information import PtsV2PaymentsPost201ResponseOrderInformation
from .pts_v2_payments_post201_response_order_information_amount_details import PtsV2PaymentsPost201ResponseOrderInformationAmountDetails
from .pts_v2_payments_post201_response_order_information_invoice_details import PtsV2PaymentsPost201ResponseOrderInformationInvoiceDetails
from .pts_v2_payments_post201_response_payment_information import PtsV2PaymentsPost201ResponsePaymentInformation
from .pts_v2_payments_post201_response_payment_information_account_features import PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures
from .pts_v2_payments_post201_response_payment_information_account_features_balances import PtsV2PaymentsPost201ResponsePaymentInformationAccountFeaturesBalances
from .pts_v2_payments_post201_response_payment_information_bank import PtsV2PaymentsPost201ResponsePaymentInformationBank
from .pts_v2_payments_post201_response_payment_information_bank_account import PtsV2PaymentsPost201ResponsePaymentInformationBankAccount
from .pts_v2_payments_post201_response_payment_information_card import PtsV2PaymentsPost201ResponsePaymentInformationCard
from .pts_v2_payments_post201_response_payment_information_instrument_identifier import PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier
from .pts_v2_payments_post201_response_payment_information_tokenized_card import PtsV2PaymentsPost201ResponsePaymentInformationTokenizedCard
from .pts_v2_payments_post201_response_point_of_sale_information import PtsV2PaymentsPost201ResponsePointOfSaleInformation
from .pts_v2_payments_post201_response_point_of_sale_information_emv import PtsV2PaymentsPost201ResponsePointOfSaleInformationEmv
from .pts_v2_payments_post201_response_processing_information import PtsV2PaymentsPost201ResponseProcessingInformation
from .pts_v2_payments_post201_response_processing_information_bank_transfer_options import PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions
from .pts_v2_payments_post201_response_processor_information import PtsV2PaymentsPost201ResponseProcessorInformation
from .pts_v2_payments_post201_response_processor_information_ach_verification import PtsV2PaymentsPost201ResponseProcessorInformationAchVerification
from .pts_v2_payments_post201_response_processor_information_avs import PtsV2PaymentsPost201ResponseProcessorInformationAvs
from .pts_v2_payments_post201_response_processor_information_card_verification import PtsV2PaymentsPost201ResponseProcessorInformationCardVerification
from .pts_v2_payments_post201_response_processor_information_consumer_authentication_response import PtsV2PaymentsPost201ResponseProcessorInformationConsumerAuthenticationResponse
from .pts_v2_payments_post201_response_processor_information_customer import PtsV2PaymentsPost201ResponseProcessorInformationCustomer
from .pts_v2_payments_post201_response_processor_information_electronic_verification_results import PtsV2PaymentsPost201ResponseProcessorInformationElectronicVerificationResults
from .pts_v2_payments_post201_response_processor_information_merchant_advice import PtsV2PaymentsPost201ResponseProcessorInformationMerchantAdvice
from .pts_v2_payments_post201_response_processor_information_routing import PtsV2PaymentsPost201ResponseProcessorInformationRouting
from .pts_v2_payments_post201_response_risk_information import PtsV2PaymentsPost201ResponseRiskInformation
from .pts_v2_payments_post201_response_risk_information_info_codes import PtsV2PaymentsPost201ResponseRiskInformationInfoCodes
from .pts_v2_payments_post201_response_risk_information_ip_address import PtsV2PaymentsPost201ResponseRiskInformationIpAddress
from .pts_v2_payments_post201_response_risk_information_profile import PtsV2PaymentsPost201ResponseRiskInformationProfile
from .pts_v2_payments_post201_response_risk_information_providers import PtsV2PaymentsPost201ResponseRiskInformationProviders
from .pts_v2_payments_post201_response_risk_information_providers_provider_name import PtsV2PaymentsPost201ResponseRiskInformationProvidersProviderName
from .pts_v2_payments_post201_response_risk_information_rules import PtsV2PaymentsPost201ResponseRiskInformationRules
from .pts_v2_payments_post201_response_risk_information_score import PtsV2PaymentsPost201ResponseRiskInformationScore
from .pts_v2_payments_post201_response_risk_information_travel import PtsV2PaymentsPost201ResponseRiskInformationTravel
from .pts_v2_payments_post201_response_risk_information_travel_actual_final_destination import PtsV2PaymentsPost201ResponseRiskInformationTravelActualFinalDestination
from .pts_v2_payments_post201_response_risk_information_travel_first_departure import PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDeparture
from .pts_v2_payments_post201_response_risk_information_travel_first_destination import PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDestination
from .pts_v2_payments_post201_response_risk_information_travel_last_destination import PtsV2PaymentsPost201ResponseRiskInformationTravelLastDestination
from .pts_v2_payments_post201_response_risk_information_velocity import PtsV2PaymentsPost201ResponseRiskInformationVelocity
from .pts_v2_payments_post201_response_risk_information_velocity_morphing import PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing
from .pts_v2_payments_post201_response_token_information import PtsV2PaymentsPost201ResponseTokenInformation
from .pts_v2_payments_post201_response_token_information_customer import PtsV2PaymentsPost201ResponseTokenInformationCustomer
from .pts_v2_payments_post201_response_token_information_instrument_identifier import PtsV2PaymentsPost201ResponseTokenInformationInstrumentIdentifier
from .pts_v2_payments_post201_response_token_information_payment_instrument import PtsV2PaymentsPost201ResponseTokenInformationPaymentInstrument
from .pts_v2_payments_post201_response_token_information_shipping_address import PtsV2PaymentsPost201ResponseTokenInformationShippingAddress
from .pts_v2_payments_post400_response import PtsV2PaymentsPost400Response
from .pts_v2_payments_post502_response import PtsV2PaymentsPost502Response
from .pts_v2_payments_refund_post201_response import PtsV2PaymentsRefundPost201Response
from .pts_v2_payments_refund_post201_response__links import PtsV2PaymentsRefundPost201ResponseLinks
from .pts_v2_payments_refund_post201_response_order_information import PtsV2PaymentsRefundPost201ResponseOrderInformation
from .pts_v2_payments_refund_post201_response_processor_information import PtsV2PaymentsRefundPost201ResponseProcessorInformation
from .pts_v2_payments_refund_post201_response_refund_amount_details import PtsV2PaymentsRefundPost201ResponseRefundAmountDetails
from .pts_v2_payments_refund_post400_response import PtsV2PaymentsRefundPost400Response
from .pts_v2_payments_reversals_post201_response import PtsV2PaymentsReversalsPost201Response
from .pts_v2_payments_reversals_post201_response_authorization_information import PtsV2PaymentsReversalsPost201ResponseAuthorizationInformation
from .pts_v2_payments_reversals_post201_response_issuer_information import PtsV2PaymentsReversalsPost201ResponseIssuerInformation
from .pts_v2_payments_reversals_post201_response_processor_information import PtsV2PaymentsReversalsPost201ResponseProcessorInformation
from .pts_v2_payments_reversals_post201_response_reversal_amount_details import PtsV2PaymentsReversalsPost201ResponseReversalAmountDetails
from .pts_v2_payments_reversals_post400_response import PtsV2PaymentsReversalsPost400Response
from .pts_v2_payments_voids_post201_response import PtsV2PaymentsVoidsPost201Response
from .pts_v2_payments_voids_post201_response_processor_information import PtsV2PaymentsVoidsPost201ResponseProcessorInformation
from .pts_v2_payments_voids_post201_response_void_amount_details import PtsV2PaymentsVoidsPost201ResponseVoidAmountDetails
from .pts_v2_payments_voids_post400_response import PtsV2PaymentsVoidsPost400Response
from .pts_v2_payouts_post201_response import PtsV2PayoutsPost201Response
from .pts_v2_payouts_post201_response_error_information import PtsV2PayoutsPost201ResponseErrorInformation
from .pts_v2_payouts_post201_response_merchant_information import PtsV2PayoutsPost201ResponseMerchantInformation
from .pts_v2_payouts_post201_response_merchant_information_merchant_descriptor import PtsV2PayoutsPost201ResponseMerchantInformationMerchantDescriptor
from .pts_v2_payouts_post201_response_order_information import PtsV2PayoutsPost201ResponseOrderInformation
from .pts_v2_payouts_post201_response_order_information_amount_details import PtsV2PayoutsPost201ResponseOrderInformationAmountDetails
from .pts_v2_payouts_post201_response_processor_information import PtsV2PayoutsPost201ResponseProcessorInformation
from .pts_v2_payouts_post201_response_recipient_information import PtsV2PayoutsPost201ResponseRecipientInformation
from .pts_v2_payouts_post201_response_recipient_information_card import PtsV2PayoutsPost201ResponseRecipientInformationCard
from .pts_v2_payouts_post400_response import PtsV2PayoutsPost400Response
from .ptsv2credits_installment_information import Ptsv2creditsInstallmentInformation
from .ptsv2credits_processing_information import Ptsv2creditsProcessingInformation
from .ptsv2credits_processing_information_bank_transfer_options import Ptsv2creditsProcessingInformationBankTransferOptions
from .ptsv2credits_processing_information_electronic_benefits_transfer import Ptsv2creditsProcessingInformationElectronicBenefitsTransfer
from .ptsv2credits_processing_information_japan_payment_options import Ptsv2creditsProcessingInformationJapanPaymentOptions
from .ptsv2credits_processing_information_purchase_options import Ptsv2creditsProcessingInformationPurchaseOptions
from .ptsv2payments_acquirer_information import Ptsv2paymentsAcquirerInformation
from .ptsv2payments_aggregator_information import Ptsv2paymentsAggregatorInformation
from .ptsv2payments_aggregator_information_sub_merchant import Ptsv2paymentsAggregatorInformationSubMerchant
from .ptsv2payments_buyer_information import Ptsv2paymentsBuyerInformation
from .ptsv2payments_buyer_information_personal_identification import Ptsv2paymentsBuyerInformationPersonalIdentification
from .ptsv2payments_client_reference_information import Ptsv2paymentsClientReferenceInformation
from .ptsv2payments_client_reference_information_partner import Ptsv2paymentsClientReferenceInformationPartner
from .ptsv2payments_consumer_authentication_information import Ptsv2paymentsConsumerAuthenticationInformation
from .ptsv2payments_consumer_authentication_information_strong_authentication import Ptsv2paymentsConsumerAuthenticationInformationStrongAuthentication
from .ptsv2payments_device_information import Ptsv2paymentsDeviceInformation
from .ptsv2payments_device_information_raw_data import Ptsv2paymentsDeviceInformationRawData
from .ptsv2payments_health_care_information import Ptsv2paymentsHealthCareInformation
from .ptsv2payments_health_care_information_amount_details import Ptsv2paymentsHealthCareInformationAmountDetails
from .ptsv2payments_installment_information import Ptsv2paymentsInstallmentInformation
from .ptsv2payments_issuer_information import Ptsv2paymentsIssuerInformation
from .ptsv2payments_merchant_defined_information import Ptsv2paymentsMerchantDefinedInformation
from .ptsv2payments_merchant_information import Ptsv2paymentsMerchantInformation
from .ptsv2payments_merchant_information_merchant_descriptor import Ptsv2paymentsMerchantInformationMerchantDescriptor
from .ptsv2payments_merchant_information_service_fee_descriptor import Ptsv2paymentsMerchantInformationServiceFeeDescriptor
from .ptsv2payments_order_information import Ptsv2paymentsOrderInformation
from .ptsv2payments_order_information_amount_details import Ptsv2paymentsOrderInformationAmountDetails
from .ptsv2payments_order_information_amount_details_amex_additional_amounts import Ptsv2paymentsOrderInformationAmountDetailsAmexAdditionalAmounts
from .ptsv2payments_order_information_amount_details_currency_conversion import Ptsv2paymentsOrderInformationAmountDetailsCurrencyConversion
from .ptsv2payments_order_information_amount_details_surcharge import Ptsv2paymentsOrderInformationAmountDetailsSurcharge
from .ptsv2payments_order_information_amount_details_tax_details import Ptsv2paymentsOrderInformationAmountDetailsTaxDetails
from .ptsv2payments_order_information_bill_to import Ptsv2paymentsOrderInformationBillTo
from .ptsv2payments_order_information_bill_to_company import Ptsv2paymentsOrderInformationBillToCompany
from .ptsv2payments_order_information_invoice_details import Ptsv2paymentsOrderInformationInvoiceDetails
from .ptsv2payments_order_information_invoice_details_transaction_advice_addendum import Ptsv2paymentsOrderInformationInvoiceDetailsTransactionAdviceAddendum
from .ptsv2payments_order_information_line_items import Ptsv2paymentsOrderInformationLineItems
from .ptsv2payments_order_information_passenger import Ptsv2paymentsOrderInformationPassenger
from .ptsv2payments_order_information_ship_to import Ptsv2paymentsOrderInformationShipTo
from .ptsv2payments_order_information_shipping_details import Ptsv2paymentsOrderInformationShippingDetails
from .ptsv2payments_payment_information import Ptsv2paymentsPaymentInformation
from .ptsv2payments_payment_information_bank import Ptsv2paymentsPaymentInformationBank
from .ptsv2payments_payment_information_bank_account import Ptsv2paymentsPaymentInformationBankAccount
from .ptsv2payments_payment_information_card import Ptsv2paymentsPaymentInformationCard
from .ptsv2payments_payment_information_customer import Ptsv2paymentsPaymentInformationCustomer
from .ptsv2payments_payment_information_fluid_data import Ptsv2paymentsPaymentInformationFluidData
from .ptsv2payments_payment_information_instrument_identifier import Ptsv2paymentsPaymentInformationInstrumentIdentifier
from .ptsv2payments_payment_information_legacy_token import Ptsv2paymentsPaymentInformationLegacyToken
from .ptsv2payments_payment_information_payment_instrument import Ptsv2paymentsPaymentInformationPaymentInstrument
from .ptsv2payments_payment_information_payment_type import Ptsv2paymentsPaymentInformationPaymentType
from .ptsv2payments_payment_information_payment_type_method import Ptsv2paymentsPaymentInformationPaymentTypeMethod
from .ptsv2payments_payment_information_shipping_address import Ptsv2paymentsPaymentInformationShippingAddress
from .ptsv2payments_payment_information_tokenized_card import Ptsv2paymentsPaymentInformationTokenizedCard
from .ptsv2payments_point_of_sale_information import Ptsv2paymentsPointOfSaleInformation
from .ptsv2payments_point_of_sale_information_emv import Ptsv2paymentsPointOfSaleInformationEmv
from .ptsv2payments_processing_information import Ptsv2paymentsProcessingInformation
from .ptsv2payments_processing_information_authorization_options import Ptsv2paymentsProcessingInformationAuthorizationOptions
from .ptsv2payments_processing_information_authorization_options_initiator import Ptsv2paymentsProcessingInformationAuthorizationOptionsInitiator
from .ptsv2payments_merchant_initiated_transaction import Ptsv2paymentsProcessingInformationAuthorizationOptionsInitiatorMerchantInitiatedTransaction
from .ptsv2payments_processing_information_bank_transfer_options import Ptsv2paymentsProcessingInformationBankTransferOptions
from .ptsv2payments_processing_information_capture_options import Ptsv2paymentsProcessingInformationCaptureOptions
from .ptsv2payments_processing_information_electronic_benefits_transfer import Ptsv2paymentsProcessingInformationElectronicBenefitsTransfer
from .ptsv2payments_processing_information_japan_payment_options import Ptsv2paymentsProcessingInformationJapanPaymentOptions
from .ptsv2payments_processing_information_loan_options import Ptsv2paymentsProcessingInformationLoanOptions
from .ptsv2payments_processing_information_purchase_options import Ptsv2paymentsProcessingInformationPurchaseOptions
from .ptsv2payments_processing_information_recurring_options import Ptsv2paymentsProcessingInformationRecurringOptions
from .ptsv2payments_promotion_information import Ptsv2paymentsPromotionInformation
from .ptsv2payments_recipient_information import Ptsv2paymentsRecipientInformation
from .ptsv2payments_recurring_payment_information import Ptsv2paymentsRecurringPaymentInformation
from .ptsv2payments_risk_information import Ptsv2paymentsRiskInformation
from .ptsv2payments_risk_information_buyer_history import Ptsv2paymentsRiskInformationBuyerHistory
from .ptsv2payments_risk_information_buyer_history_account_history import Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory
from .ptsv2payments_risk_information_buyer_history_customer_account import Ptsv2paymentsRiskInformationBuyerHistoryCustomerAccount
from .ptsv2payments_risk_information_profile import Ptsv2paymentsRiskInformationProfile
from .ptsv2payments_token_information import Ptsv2paymentsTokenInformation
from .ptsv2payments_token_information_payment_instrument import Ptsv2paymentsTokenInformationPaymentInstrument
from .ptsv2payments_token_information_shipping_address import Ptsv2paymentsTokenInformationShippingAddress
from .ptsv2payments_travel_information import Ptsv2paymentsTravelInformation
from .ptsv2payments_travel_information_agency import Ptsv2paymentsTravelInformationAgency
from .ptsv2payments_travel_information_auto_rental import Ptsv2paymentsTravelInformationAutoRental
from .ptsv2payments_travel_information_auto_rental_rental_address import Ptsv2paymentsTravelInformationAutoRentalRentalAddress
from .ptsv2payments_travel_information_auto_rental_return_address import Ptsv2paymentsTravelInformationAutoRentalReturnAddress
from .ptsv2payments_travel_information_auto_rental_tax_details import Ptsv2paymentsTravelInformationAutoRentalTaxDetails
from .ptsv2payments_travel_information_lodging import Ptsv2paymentsTravelInformationLodging
from .ptsv2payments_travel_information_lodging_room import Ptsv2paymentsTravelInformationLodgingRoom
from .ptsv2payments_travel_information_transit import Ptsv2paymentsTravelInformationTransit
from .ptsv2payments_travel_information_transit_airline import Ptsv2paymentsTravelInformationTransitAirline
from .ptsv2payments_travel_information_transit_airline_ancillary_information import Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
from .ptsv2payments_travel_information_transit_airline_ancillary_information_service import Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformationService
from .ptsv2payments_travel_information_transit_airline_legs import Ptsv2paymentsTravelInformationTransitAirlineLegs
from .ptsv2payments_travel_information_transit_airline_ticket_issuer import Ptsv2paymentsTravelInformationTransitAirlineTicketIssuer
from .ptsv2paymentsid_client_reference_information import Ptsv2paymentsidClientReferenceInformation
from .ptsv2paymentsid_client_reference_information_partner import Ptsv2paymentsidClientReferenceInformationPartner
from .ptsv2paymentsid_merchant_information import Ptsv2paymentsidMerchantInformation
from .ptsv2paymentsid_order_information import Ptsv2paymentsidOrderInformation
from .ptsv2paymentsid_order_information_amount_details import Ptsv2paymentsidOrderInformationAmountDetails
from .ptsv2paymentsid_processing_information import Ptsv2paymentsidProcessingInformation
from .ptsv2paymentsid_processing_information_authorization_options import Ptsv2paymentsidProcessingInformationAuthorizationOptions
from .ptsv2paymentsid_processing_information_authorization_options_initiator import Ptsv2paymentsidProcessingInformationAuthorizationOptionsInitiator
from .ptsv2paymentsid_travel_information import Ptsv2paymentsidTravelInformation
from .ptsv2paymentsidcaptures_aggregator_information import Ptsv2paymentsidcapturesAggregatorInformation
from .ptsv2paymentsidcaptures_aggregator_information_sub_merchant import Ptsv2paymentsidcapturesAggregatorInformationSubMerchant
from .ptsv2paymentsidcaptures_buyer_information import Ptsv2paymentsidcapturesBuyerInformation
from .ptsv2paymentsidcaptures_device_information import Ptsv2paymentsidcapturesDeviceInformation
from .ptsv2paymentsidcaptures_installment_information import Ptsv2paymentsidcapturesInstallmentInformation
from .ptsv2paymentsidcaptures_merchant_information import Ptsv2paymentsidcapturesMerchantInformation
from .ptsv2paymentsidcaptures_order_information import Ptsv2paymentsidcapturesOrderInformation
from .ptsv2paymentsidcaptures_order_information_amount_details import Ptsv2paymentsidcapturesOrderInformationAmountDetails
from .ptsv2paymentsidcaptures_order_information_bill_to import Ptsv2paymentsidcapturesOrderInformationBillTo
from .ptsv2paymentsidcaptures_order_information_invoice_details import Ptsv2paymentsidcapturesOrderInformationInvoiceDetails
from .ptsv2paymentsidcaptures_order_information_ship_to import Ptsv2paymentsidcapturesOrderInformationShipTo
from .ptsv2paymentsidcaptures_order_information_shipping_details import Ptsv2paymentsidcapturesOrderInformationShippingDetails
from .ptsv2paymentsidcaptures_payment_information import Ptsv2paymentsidcapturesPaymentInformation
from .ptsv2paymentsidcaptures_payment_information_card import Ptsv2paymentsidcapturesPaymentInformationCard
from .ptsv2paymentsidcaptures_point_of_sale_information import Ptsv2paymentsidcapturesPointOfSaleInformation
from .ptsv2paymentsidcaptures_point_of_sale_information_emv import Ptsv2paymentsidcapturesPointOfSaleInformationEmv
from .ptsv2paymentsidcaptures_processing_information import Ptsv2paymentsidcapturesProcessingInformation
from .ptsv2paymentsidcaptures_processing_information_authorization_options import Ptsv2paymentsidcapturesProcessingInformationAuthorizationOptions
from .ptsv2paymentsidcaptures_processing_information_capture_options import Ptsv2paymentsidcapturesProcessingInformationCaptureOptions
from .ptsv2paymentsidrefunds_merchant_information import Ptsv2paymentsidrefundsMerchantInformation
from .ptsv2paymentsidrefunds_order_information import Ptsv2paymentsidrefundsOrderInformation
from .ptsv2paymentsidrefunds_order_information_line_items import Ptsv2paymentsidrefundsOrderInformationLineItems
from .ptsv2paymentsidrefunds_payment_information import Ptsv2paymentsidrefundsPaymentInformation
from .ptsv2paymentsidrefunds_payment_information_card import Ptsv2paymentsidrefundsPaymentInformationCard
from .ptsv2paymentsidrefunds_point_of_sale_information import Ptsv2paymentsidrefundsPointOfSaleInformation
from .ptsv2paymentsidrefunds_processing_information import Ptsv2paymentsidrefundsProcessingInformation
from .ptsv2paymentsidrefunds_processing_information_recurring_options import Ptsv2paymentsidrefundsProcessingInformationRecurringOptions
from .ptsv2paymentsidreversals_client_reference_information import Ptsv2paymentsidreversalsClientReferenceInformation
from .ptsv2paymentsidreversals_client_reference_information_partner import Ptsv2paymentsidreversalsClientReferenceInformationPartner
from .ptsv2paymentsidreversals_order_information import Ptsv2paymentsidreversalsOrderInformation
from .ptsv2paymentsidreversals_order_information_amount_details import Ptsv2paymentsidreversalsOrderInformationAmountDetails
from .ptsv2paymentsidreversals_order_information_line_items import Ptsv2paymentsidreversalsOrderInformationLineItems
from .ptsv2paymentsidreversals_point_of_sale_information import Ptsv2paymentsidreversalsPointOfSaleInformation
from .ptsv2paymentsidreversals_point_of_sale_information_emv import Ptsv2paymentsidreversalsPointOfSaleInformationEmv
from .ptsv2paymentsidreversals_processing_information import Ptsv2paymentsidreversalsProcessingInformation
from .ptsv2paymentsidreversals_reversal_information import Ptsv2paymentsidreversalsReversalInformation
from .ptsv2paymentsidreversals_reversal_information_amount_details import Ptsv2paymentsidreversalsReversalInformationAmountDetails
from .ptsv2paymentsidvoids_payment_information import Ptsv2paymentsidvoidsPaymentInformation
from .ptsv2payouts_client_reference_information import Ptsv2payoutsClientReferenceInformation
from .ptsv2payouts_merchant_information import Ptsv2payoutsMerchantInformation
from .ptsv2payouts_merchant_information_merchant_descriptor import Ptsv2payoutsMerchantInformationMerchantDescriptor
from .ptsv2payouts_order_information import Ptsv2payoutsOrderInformation
from .ptsv2payouts_order_information_amount_details import Ptsv2payoutsOrderInformationAmountDetails
from .ptsv2payouts_order_information_amount_details_surcharge import Ptsv2payoutsOrderInformationAmountDetailsSurcharge
from .ptsv2payouts_order_information_bill_to import Ptsv2payoutsOrderInformationBillTo
from .ptsv2payouts_payment_information import Ptsv2payoutsPaymentInformation
from .ptsv2payouts_payment_information_card import Ptsv2payoutsPaymentInformationCard
from .ptsv2payouts_processing_information import Ptsv2payoutsProcessingInformation
from .ptsv2payouts_processing_information_payouts_options import Ptsv2payoutsProcessingInformationPayoutsOptions
from .ptsv2payouts_recipient_information import Ptsv2payoutsRecipientInformation
from .ptsv2payouts_sender_information import Ptsv2payoutsSenderInformation
from .ptsv2payouts_sender_information_account import Ptsv2payoutsSenderInformationAccount
from .refund_capture_request import RefundCaptureRequest
from .refund_payment_request import RefundPaymentRequest
from .reporting_v3_conversion_details_get200_response import ReportingV3ConversionDetailsGet200Response
from .reporting_v3_conversion_details_get200_response_conversion_details import ReportingV3ConversionDetailsGet200ResponseConversionDetails
from .reporting_v3_conversion_details_get200_response_notes import ReportingV3ConversionDetailsGet200ResponseNotes
from .reporting_v3_net_fundings_get200_response import ReportingV3NetFundingsGet200Response
from .reporting_v3_net_fundings_get200_response_net_funding_summaries import ReportingV3NetFundingsGet200ResponseNetFundingSummaries
from .reporting_v3_net_fundings_get200_response_total_purchases import ReportingV3NetFundingsGet200ResponseTotalPurchases
from .reporting_v3_notificationof_changes_get200_response import ReportingV3NotificationofChangesGet200Response
from .reporting_v3_notificationof_changes_get200_response_notification_of_changes import ReportingV3NotificationofChangesGet200ResponseNotificationOfChanges
from .reporting_v3_payment_batch_summaries_get200_response import ReportingV3PaymentBatchSummariesGet200Response
from .reporting_v3_payment_batch_summaries_get200_response_payment_batch_summaries import ReportingV3PaymentBatchSummariesGet200ResponsePaymentBatchSummaries
from .reporting_v3_purchase_refund_details_get200_response import ReportingV3PurchaseRefundDetailsGet200Response
from .reporting_v3_purchase_refund_details_get200_response_authorizations import ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations
from .reporting_v3_purchase_refund_details_get200_response_fee_and_funding_details import ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails
from .reporting_v3_purchase_refund_details_get200_response_others import ReportingV3PurchaseRefundDetailsGet200ResponseOthers
from .reporting_v3_purchase_refund_details_get200_response_request_details import ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails
from .reporting_v3_purchase_refund_details_get200_response_settlement_statuses import ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses
from .reporting_v3_purchase_refund_details_get200_response_settlements import ReportingV3PurchaseRefundDetailsGet200ResponseSettlements
from .reporting_v3_report_definitions_get200_response import ReportingV3ReportDefinitionsGet200Response
from .reporting_v3_report_definitions_get200_response_report_definitions import ReportingV3ReportDefinitionsGet200ResponseReportDefinitions
from .reporting_v3_report_definitions_name_get200_response import ReportingV3ReportDefinitionsNameGet200Response
from .reporting_v3_report_definitions_name_get200_response_attributes import ReportingV3ReportDefinitionsNameGet200ResponseAttributes
from .reporting_v3_report_definitions_name_get200_response_default_settings import ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings
from .reporting_v3_report_subscriptions_get200_response import ReportingV3ReportSubscriptionsGet200Response
from .reporting_v3_report_subscriptions_get200_response_subscriptions import ReportingV3ReportSubscriptionsGet200ResponseSubscriptions
from .reporting_v3_reports_get200_response import ReportingV3ReportsGet200Response
from .reporting_v3_reports_get200_response__link import ReportingV3ReportsGet200ResponseLink
from .reporting_v3_reports_get200_response__link_report_download import ReportingV3ReportsGet200ResponseLinkReportDownload
from .reporting_v3_reports_get200_response_report_search_results import ReportingV3ReportsGet200ResponseReportSearchResults
from .reporting_v3_reports_id_get200_response import ReportingV3ReportsIdGet200Response
from .reportingv3_report_downloads_get400_response import Reportingv3ReportDownloadsGet400Response
from .reportingv3_report_downloads_get400_response_details import Reportingv3ReportDownloadsGet400ResponseDetails
from .reportingv3reports_report_preferences import Reportingv3reportsReportPreferences
from .response_status import ResponseStatus
from .response_status_details import ResponseStatusDetails
from .risk_v1_address_verifications_post201_response import RiskV1AddressVerificationsPost201Response
from .risk_v1_address_verifications_post201_response_address_verification_information import RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation
from .risk_v1_address_verifications_post201_response_address_verification_information_bar_code import RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationBarCode
from .risk_v1_address_verifications_post201_response_address_verification_information_standard_address import RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddress
from .risk_v1_address_verifications_post201_response_address_verification_information_standard_address_address1 import RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddressAddress1
from .risk_v1_address_verifications_post201_response_error_information import RiskV1AddressVerificationsPost201ResponseErrorInformation
from .risk_v1_authentication_results_post201_response import RiskV1AuthenticationResultsPost201Response
from .risk_v1_authentication_results_post201_response_consumer_authentication_information import RiskV1AuthenticationResultsPost201ResponseConsumerAuthenticationInformation
from .risk_v1_authentication_setups_post201_response import RiskV1AuthenticationSetupsPost201Response
from .risk_v1_authentication_setups_post201_response_consumer_authentication_information import RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation
from .risk_v1_authentication_setups_post201_response_error_information import RiskV1AuthenticationSetupsPost201ResponseErrorInformation
from .risk_v1_authentications_post201_response import RiskV1AuthenticationsPost201Response
from .risk_v1_authentications_post201_response_error_information import RiskV1AuthenticationsPost201ResponseErrorInformation
from .risk_v1_authentications_post400_response import RiskV1AuthenticationsPost400Response
from .risk_v1_authentications_post400_response_1 import RiskV1AuthenticationsPost400Response1
from .risk_v1_decisions_post201_response import RiskV1DecisionsPost201Response
from .risk_v1_decisions_post201_response_consumer_authentication_information import RiskV1DecisionsPost201ResponseConsumerAuthenticationInformation
from .risk_v1_decisions_post201_response_error_information import RiskV1DecisionsPost201ResponseErrorInformation
from .risk_v1_decisions_post201_response_order_information import RiskV1DecisionsPost201ResponseOrderInformation
from .risk_v1_decisions_post201_response_order_information_amount_details import RiskV1DecisionsPost201ResponseOrderInformationAmountDetails
from .risk_v1_decisions_post201_response_payment_information import RiskV1DecisionsPost201ResponsePaymentInformation
from .risk_v1_decisions_post400_response import RiskV1DecisionsPost400Response
from .risk_v1_decisions_post400_response_1 import RiskV1DecisionsPost400Response1
from .risk_v1_export_compliance_inquiries_post201_response import RiskV1ExportComplianceInquiriesPost201Response
from .risk_v1_export_compliance_inquiries_post201_response_error_information import RiskV1ExportComplianceInquiriesPost201ResponseErrorInformation
from .risk_v1_export_compliance_inquiries_post201_response_export_compliance_information import RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation
from .risk_v1_export_compliance_inquiries_post201_response_export_compliance_information_watch_list import RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchList
from .risk_v1_export_compliance_inquiries_post201_response_export_compliance_information_watch_list_matches import RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches
from .risk_v1_update_post201_response import RiskV1UpdatePost201Response
from .riskv1addressverifications_buyer_information import Riskv1addressverificationsBuyerInformation
from .riskv1addressverifications_client_reference_information import Riskv1addressverificationsClientReferenceInformation
from .riskv1addressverifications_order_information import Riskv1addressverificationsOrderInformation
from .riskv1addressverifications_order_information_bill_to import Riskv1addressverificationsOrderInformationBillTo
from .riskv1addressverifications_order_information_line_items import Riskv1addressverificationsOrderInformationLineItems
from .riskv1addressverifications_order_information_ship_to import Riskv1addressverificationsOrderInformationShipTo
from .riskv1authenticationresults_consumer_authentication_information import Riskv1authenticationresultsConsumerAuthenticationInformation
from .riskv1authenticationresults_order_information import Riskv1authenticationresultsOrderInformation
from .riskv1authenticationresults_order_information_line_items import Riskv1authenticationresultsOrderInformationLineItems
from .riskv1authenticationresults_payment_information import Riskv1authenticationresultsPaymentInformation
from .riskv1authenticationresults_payment_information_card import Riskv1authenticationresultsPaymentInformationCard
from .riskv1authenticationresults_payment_information_tokenized_card import Riskv1authenticationresultsPaymentInformationTokenizedCard
from .riskv1authentications_buyer_information import Riskv1authenticationsBuyerInformation
from .riskv1authentications_device_information import Riskv1authenticationsDeviceInformation
from .riskv1authentications_order_information import Riskv1authenticationsOrderInformation
from .riskv1authentications_order_information_amount_details import Riskv1authenticationsOrderInformationAmountDetails
from .riskv1authentications_order_information_bill_to import Riskv1authenticationsOrderInformationBillTo
from .riskv1authentications_order_information_line_items import Riskv1authenticationsOrderInformationLineItems
from .riskv1authentications_payment_information import Riskv1authenticationsPaymentInformation
from .riskv1authentications_payment_information_card import Riskv1authenticationsPaymentInformationCard
from .riskv1authentications_payment_information_tokenized_card import Riskv1authenticationsPaymentInformationTokenizedCard
from .riskv1authentications_risk_information import Riskv1authenticationsRiskInformation
from .riskv1authentications_travel_information import Riskv1authenticationsTravelInformation
from .riskv1authenticationsetups_client_reference_information import Riskv1authenticationsetupsClientReferenceInformation
from .riskv1authenticationsetups_payment_information import Riskv1authenticationsetupsPaymentInformation
from .riskv1authenticationsetups_payment_information_card import Riskv1authenticationsetupsPaymentInformationCard
from .riskv1authenticationsetups_payment_information_customer import Riskv1authenticationsetupsPaymentInformationCustomer
from .riskv1authenticationsetups_payment_information_fluid_data import Riskv1authenticationsetupsPaymentInformationFluidData
from .riskv1authenticationsetups_payment_information_tokenized_card import Riskv1authenticationsetupsPaymentInformationTokenizedCard
from .riskv1authenticationsetups_processing_information import Riskv1authenticationsetupsProcessingInformation
from .riskv1authenticationsetups_token_information import Riskv1authenticationsetupsTokenInformation
from .riskv1decisions_buyer_information import Riskv1decisionsBuyerInformation
from .riskv1decisions_client_reference_information import Riskv1decisionsClientReferenceInformation
from .riskv1decisions_consumer_authentication_information import Riskv1decisionsConsumerAuthenticationInformation
from .riskv1decisions_consumer_authentication_information_strong_authentication import Riskv1decisionsConsumerAuthenticationInformationStrongAuthentication
from .riskv1decisions_device_information import Riskv1decisionsDeviceInformation
from .riskv1decisions_merchant_defined_information import Riskv1decisionsMerchantDefinedInformation
from .riskv1decisions_merchant_information import Riskv1decisionsMerchantInformation
from .riskv1decisions_merchant_information_merchant_descriptor import Riskv1decisionsMerchantInformationMerchantDescriptor
from .riskv1decisions_order_information import Riskv1decisionsOrderInformation
from .riskv1decisions_order_information_amount_details import Riskv1decisionsOrderInformationAmountDetails
from .riskv1decisions_order_information_bill_to import Riskv1decisionsOrderInformationBillTo
from .riskv1decisions_order_information_line_items import Riskv1decisionsOrderInformationLineItems
from .riskv1decisions_order_information_ship_to import Riskv1decisionsOrderInformationShipTo
from .riskv1decisions_order_information_shipping_details import Riskv1decisionsOrderInformationShippingDetails
from .riskv1decisions_payment_information import Riskv1decisionsPaymentInformation
from .riskv1decisions_payment_information_card import Riskv1decisionsPaymentInformationCard
from .riskv1decisions_payment_information_tokenized_card import Riskv1decisionsPaymentInformationTokenizedCard
from .riskv1decisions_processing_information import Riskv1decisionsProcessingInformation
from .riskv1decisions_processor_information import Riskv1decisionsProcessorInformation
from .riskv1decisions_processor_information_avs import Riskv1decisionsProcessorInformationAvs
from .riskv1decisions_processor_information_card_verification import Riskv1decisionsProcessorInformationCardVerification
from .riskv1decisions_risk_information import Riskv1decisionsRiskInformation
from .riskv1decisions_travel_information import Riskv1decisionsTravelInformation
from .riskv1decisions_travel_information_legs import Riskv1decisionsTravelInformationLegs
from .riskv1decisions_travel_information_passengers import Riskv1decisionsTravelInformationPassengers
from .riskv1decisionsidmarking_risk_information import Riskv1decisionsidmarkingRiskInformation
from .riskv1decisionsidmarking_risk_information_marking_details import Riskv1decisionsidmarkingRiskInformationMarkingDetails
from .riskv1exportcomplianceinquiries_device_information import Riskv1exportcomplianceinquiriesDeviceInformation
from .riskv1exportcomplianceinquiries_export_compliance_information import Riskv1exportcomplianceinquiriesExportComplianceInformation
from .riskv1exportcomplianceinquiries_export_compliance_information_weights import Riskv1exportcomplianceinquiriesExportComplianceInformationWeights
from .riskv1exportcomplianceinquiries_order_information import Riskv1exportcomplianceinquiriesOrderInformation
from .riskv1exportcomplianceinquiries_order_information_bill_to import Riskv1exportcomplianceinquiriesOrderInformationBillTo
from .riskv1exportcomplianceinquiries_order_information_bill_to_company import Riskv1exportcomplianceinquiriesOrderInformationBillToCompany
from .riskv1exportcomplianceinquiries_order_information_line_items import Riskv1exportcomplianceinquiriesOrderInformationLineItems
from .riskv1exportcomplianceinquiries_order_information_ship_to import Riskv1exportcomplianceinquiriesOrderInformationShipTo
from .riskv1liststypeentries_buyer_information import Riskv1liststypeentriesBuyerInformation
from .riskv1liststypeentries_device_information import Riskv1liststypeentriesDeviceInformation
from .riskv1liststypeentries_order_information import Riskv1liststypeentriesOrderInformation
from .riskv1liststypeentries_order_information_address import Riskv1liststypeentriesOrderInformationAddress
from .riskv1liststypeentries_order_information_bill_to import Riskv1liststypeentriesOrderInformationBillTo
from .riskv1liststypeentries_order_information_line_items import Riskv1liststypeentriesOrderInformationLineItems
from .riskv1liststypeentries_order_information_ship_to import Riskv1liststypeentriesOrderInformationShipTo
from .riskv1liststypeentries_payment_information import Riskv1liststypeentriesPaymentInformation
from .riskv1liststypeentries_payment_information_bank import Riskv1liststypeentriesPaymentInformationBank
from .riskv1liststypeentries_payment_information_card import Riskv1liststypeentriesPaymentInformationCard
from .riskv1liststypeentries_risk_information import Riskv1liststypeentriesRiskInformation
from .riskv1liststypeentries_risk_information_marking_details import Riskv1liststypeentriesRiskInformationMarkingDetails
from .search_request import SearchRequest
from .self_link_bean import SelfLinkBean
from .shipping_address import ShippingAddress
from .shipping_address_list_for_customer import ShippingAddressListForCustomer
from .shipping_address_list_for_customer__embedded import ShippingAddressListForCustomerEmbedded
from .shipping_address_list_for_customer__links import ShippingAddressListForCustomerLinks
from .shipping_address_list_for_customer__links_first import ShippingAddressListForCustomerLinksFirst
from .shipping_address_list_for_customer__links_last import ShippingAddressListForCustomerLinksLast
from .shipping_address_list_for_customer__links_next import ShippingAddressListForCustomerLinksNext
from .shipping_address_list_for_customer__links_prev import ShippingAddressListForCustomerLinksPrev
from .shipping_address_list_for_customer__links_self import ShippingAddressListForCustomerLinksSelf
from .shipping_address_paginated import ShippingAddressPaginated
from .tms_error import TMSError
from .tms_error_details import TMSErrorDetails
from .tms_error_response import TMSErrorResponse
from .tax_request import TaxRequest
from .tms_v2_customers_response import TmsV2CustomersResponse
from .tmsv2customers_buyer_information import Tmsv2customersBuyerInformation
from .tmsv2customers_client_reference_information import Tmsv2customersClientReferenceInformation
from .tmsv2customers_default_payment_instrument import Tmsv2customersDefaultPaymentInstrument
from .tmsv2customers_default_shipping_address import Tmsv2customersDefaultShippingAddress
from .tmsv2customers__embedded import Tmsv2customersEmbedded
from .tmsv2customers__embedded_default_payment_instrument import Tmsv2customersEmbeddedDefaultPaymentInstrument
from .tmsv2customers__embedded_default_payment_instrument_bank_account import Tmsv2customersEmbeddedDefaultPaymentInstrumentBankAccount
from .tmsv2customers__embedded_default_payment_instrument_bill_to import Tmsv2customersEmbeddedDefaultPaymentInstrumentBillTo
from .tmsv2customers__embedded_default_payment_instrument_buyer_information import Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation
from .tmsv2customers__embedded_default_payment_instrument_buyer_information_issued_by import Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformationIssuedBy
from .tmsv2customers__embedded_default_payment_instrument_buyer_information_personal_identification import Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformationPersonalIdentification
from .tmsv2customers__embedded_default_payment_instrument_card import Tmsv2customersEmbeddedDefaultPaymentInstrumentCard
from .tmsv2customers__embedded_default_payment_instrument_card_tokenized_information import Tmsv2customersEmbeddedDefaultPaymentInstrumentCardTokenizedInformation
from .tmsv2customers__embedded_default_payment_instrument__embedded import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbedded
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifier
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_bank_account import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierBankAccount
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_bill_to import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierBillTo
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_card import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierCard
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_issuer import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierIssuer
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier__links import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierLinks
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier__links_payment_instruments import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierLinksPaymentInstruments
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier__links_self import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierLinksSelf
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_metadata import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierMetadata
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_processing_information import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierProcessingInformation
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_processing_information_authorization_options import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierProcessingInformationAuthorizationOptions
from .tmsv2customers__embedded_authorization_options_initiator import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierProcessingInformationAuthorizationOptionsInitiator
from .tmsv2customers__embedded_merchant_initiated_transaction import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierProcessingInformationAuthorizationOptionsInitiatorMerchantInitiatedTransaction
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_tokenized_card import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierTokenizedCard
from .tmsv2customers__embedded_default_payment_instrument__embedded_instrument_identifier_tokenized_card_card import Tmsv2customersEmbeddedDefaultPaymentInstrumentEmbeddedInstrumentIdentifierTokenizedCardCard
from .tmsv2customers__embedded_default_payment_instrument_instrument_identifier import Tmsv2customersEmbeddedDefaultPaymentInstrumentInstrumentIdentifier
from .tmsv2customers__embedded_default_payment_instrument__links import Tmsv2customersEmbeddedDefaultPaymentInstrumentLinks
from .tmsv2customers__embedded_default_payment_instrument__links_self import Tmsv2customersEmbeddedDefaultPaymentInstrumentLinksSelf
from .tmsv2customers__embedded_default_payment_instrument_merchant_information import Tmsv2customersEmbeddedDefaultPaymentInstrumentMerchantInformation
from .tmsv2customers__embedded_default_payment_instrument_merchant_information_merchant_descriptor import Tmsv2customersEmbeddedDefaultPaymentInstrumentMerchantInformationMerchantDescriptor
from .tmsv2customers__embedded_default_payment_instrument_metadata import Tmsv2customersEmbeddedDefaultPaymentInstrumentMetadata
from .tmsv2customers__embedded_default_payment_instrument_processing_information import Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation
from .tmsv2customers__embedded_default_payment_instrument_processing_information_bank_transfer_options import Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformationBankTransferOptions
from .tmsv2customers__embedded_default_shipping_address import Tmsv2customersEmbeddedDefaultShippingAddress
from .tmsv2customers__embedded_default_shipping_address__links import Tmsv2customersEmbeddedDefaultShippingAddressLinks
from .tmsv2customers__embedded_default_shipping_address__links_customer import Tmsv2customersEmbeddedDefaultShippingAddressLinksCustomer
from .tmsv2customers__embedded_default_shipping_address__links_self import Tmsv2customersEmbeddedDefaultShippingAddressLinksSelf
from .tmsv2customers__embedded_default_shipping_address_metadata import Tmsv2customersEmbeddedDefaultShippingAddressMetadata
from .tmsv2customers__embedded_default_shipping_address_ship_to import Tmsv2customersEmbeddedDefaultShippingAddressShipTo
from .tmsv2customers__links import Tmsv2customersLinks
from .tmsv2customers__links_payment_instruments import Tmsv2customersLinksPaymentInstruments
from .tmsv2customers__links_self import Tmsv2customersLinksSelf
from .tmsv2customers__links_shipping_address import Tmsv2customersLinksShippingAddress
from .tmsv2customers_merchant_defined_information import Tmsv2customersMerchantDefinedInformation
from .tmsv2customers_metadata import Tmsv2customersMetadata
from .tmsv2customers_object_information import Tmsv2customersObjectInformation
from .tokenize_parameters import TokenizeParameters
from .tokenize_parameters_card_info import TokenizeParametersCardInfo
from .tokenize_result import TokenizeResult
from .tss_v2_transactions_get200_response import TssV2TransactionsGet200Response
from .tss_v2_transactions_get200_response_application_information import TssV2TransactionsGet200ResponseApplicationInformation
from .tss_v2_transactions_get200_response_application_information_applications import TssV2TransactionsGet200ResponseApplicationInformationApplications
from .tss_v2_transactions_get200_response_buyer_information import TssV2TransactionsGet200ResponseBuyerInformation
from .tss_v2_transactions_get200_response_client_reference_information import TssV2TransactionsGet200ResponseClientReferenceInformation
from .tss_v2_transactions_get200_response_consumer_authentication_information import TssV2TransactionsGet200ResponseConsumerAuthenticationInformation
from .tss_v2_transactions_get200_response_device_information import TssV2TransactionsGet200ResponseDeviceInformation
from .tss_v2_transactions_get200_response_error_information import TssV2TransactionsGet200ResponseErrorInformation
from .tss_v2_transactions_get200_response_fraud_marking_information import TssV2TransactionsGet200ResponseFraudMarkingInformation
from .tss_v2_transactions_get200_response_installment_information import TssV2TransactionsGet200ResponseInstallmentInformation
from .tss_v2_transactions_get200_response__links import TssV2TransactionsGet200ResponseLinks
from .tss_v2_transactions_get200_response_merchant_information import TssV2TransactionsGet200ResponseMerchantInformation
from .tss_v2_transactions_get200_response_merchant_information_merchant_descriptor import TssV2TransactionsGet200ResponseMerchantInformationMerchantDescriptor
from .tss_v2_transactions_get200_response_order_information import TssV2TransactionsGet200ResponseOrderInformation
from .tss_v2_transactions_get200_response_order_information_amount_details import TssV2TransactionsGet200ResponseOrderInformationAmountDetails
from .tss_v2_transactions_get200_response_order_information_bill_to import TssV2TransactionsGet200ResponseOrderInformationBillTo
from .tss_v2_transactions_get200_response_order_information_invoice_details import TssV2TransactionsGet200ResponseOrderInformationInvoiceDetails
from .tss_v2_transactions_get200_response_order_information_line_items import TssV2TransactionsGet200ResponseOrderInformationLineItems
from .tss_v2_transactions_get200_response_order_information_ship_to import TssV2TransactionsGet200ResponseOrderInformationShipTo
from .tss_v2_transactions_get200_response_order_information_shipping_details import TssV2TransactionsGet200ResponseOrderInformationShippingDetails
from .tss_v2_transactions_get200_response_payment_information import TssV2TransactionsGet200ResponsePaymentInformation
from .tss_v2_transactions_get200_response_payment_information_account_features import TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures
from .tss_v2_transactions_get200_response_payment_information_bank import TssV2TransactionsGet200ResponsePaymentInformationBank
from .tss_v2_transactions_get200_response_payment_information_bank_account import TssV2TransactionsGet200ResponsePaymentInformationBankAccount
from .tss_v2_transactions_get200_response_payment_information_bank_mandate import TssV2TransactionsGet200ResponsePaymentInformationBankMandate
from .tss_v2_transactions_get200_response_payment_information_card import TssV2TransactionsGet200ResponsePaymentInformationCard
from .tss_v2_transactions_get200_response_payment_information_invoice import TssV2TransactionsGet200ResponsePaymentInformationInvoice
from .tss_v2_transactions_get200_response_payment_information_payment_type import TssV2TransactionsGet200ResponsePaymentInformationPaymentType
from .tss_v2_transactions_get200_response_point_of_sale_information import TssV2TransactionsGet200ResponsePointOfSaleInformation
from .tss_v2_transactions_get200_response_processing_information import TssV2TransactionsGet200ResponseProcessingInformation
from .tss_v2_transactions_get200_response_processing_information_authorization_options import TssV2TransactionsGet200ResponseProcessingInformationAuthorizationOptions
from .tss_v2_transactions_get200_response_processing_information_bank_transfer_options import TssV2TransactionsGet200ResponseProcessingInformationBankTransferOptions
from .tss_v2_transactions_get200_response_processing_information_japan_payment_options import TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions
from .tss_v2_transactions_get200_response_processor_information import TssV2TransactionsGet200ResponseProcessorInformation
from .tss_v2_transactions_get200_response_processor_information_electronic_verification_results import TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults
from .tss_v2_transactions_get200_response_processor_information_processor import TssV2TransactionsGet200ResponseProcessorInformationProcessor
from .tss_v2_transactions_get200_response_risk_information import TssV2TransactionsGet200ResponseRiskInformation
from .tss_v2_transactions_get200_response_risk_information_profile import TssV2TransactionsGet200ResponseRiskInformationProfile
from .tss_v2_transactions_get200_response_risk_information_rules import TssV2TransactionsGet200ResponseRiskInformationRules
from .tss_v2_transactions_get200_response_risk_information_score import TssV2TransactionsGet200ResponseRiskInformationScore
from .tss_v2_transactions_get200_response_sender_information import TssV2TransactionsGet200ResponseSenderInformation
from .tss_v2_transactions_post201_response import TssV2TransactionsPost201Response
from .tss_v2_transactions_post201_response__embedded import TssV2TransactionsPost201ResponseEmbedded
from .tss_v2_transactions_post201_response__embedded_application_information import TssV2TransactionsPost201ResponseEmbeddedApplicationInformation
from .tss_v2_transactions_post201_response__embedded_application_information_applications import TssV2TransactionsPost201ResponseEmbeddedApplicationInformationApplications
from .tss_v2_transactions_post201_response__embedded_buyer_information import TssV2TransactionsPost201ResponseEmbeddedBuyerInformation
from .tss_v2_transactions_post201_response__embedded_client_reference_information import TssV2TransactionsPost201ResponseEmbeddedClientReferenceInformation
from .tss_v2_transactions_post201_response__embedded_consumer_authentication_information import TssV2TransactionsPost201ResponseEmbeddedConsumerAuthenticationInformation
from .tss_v2_transactions_post201_response__embedded_device_information import TssV2TransactionsPost201ResponseEmbeddedDeviceInformation
from .tss_v2_transactions_post201_response__embedded__links import TssV2TransactionsPost201ResponseEmbeddedLinks
from .tss_v2_transactions_post201_response__embedded_merchant_information import TssV2TransactionsPost201ResponseEmbeddedMerchantInformation
from .tss_v2_transactions_post201_response__embedded_order_information import TssV2TransactionsPost201ResponseEmbeddedOrderInformation
from .tss_v2_transactions_post201_response__embedded_order_information_bill_to import TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo
from .tss_v2_transactions_post201_response__embedded_order_information_ship_to import TssV2TransactionsPost201ResponseEmbeddedOrderInformationShipTo
from .tss_v2_transactions_post201_response__embedded_payment_information import TssV2TransactionsPost201ResponseEmbeddedPaymentInformation
from .tss_v2_transactions_post201_response__embedded_payment_information_card import TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard
from .tss_v2_transactions_post201_response__embedded_payment_information_payment_type import TssV2TransactionsPost201ResponseEmbeddedPaymentInformationPaymentType
from .tss_v2_transactions_post201_response__embedded_point_of_sale_information import TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformation
from .tss_v2_transactions_post201_response__embedded_point_of_sale_information_partner import TssV2TransactionsPost201ResponseEmbeddedPointOfSaleInformationPartner
from .tss_v2_transactions_post201_response__embedded_processing_information import TssV2TransactionsPost201ResponseEmbeddedProcessingInformation
from .tss_v2_transactions_post201_response__embedded_processor_information import TssV2TransactionsPost201ResponseEmbeddedProcessorInformation
from .tss_v2_transactions_post201_response__embedded_risk_information import TssV2TransactionsPost201ResponseEmbeddedRiskInformation
from .tss_v2_transactions_post201_response__embedded_risk_information_providers import TssV2TransactionsPost201ResponseEmbeddedRiskInformationProviders
from .tss_v2_transactions_post201_response__embedded_risk_information_providers_fingerprint import TssV2TransactionsPost201ResponseEmbeddedRiskInformationProvidersFingerprint
from .tss_v2_transactions_post201_response__embedded_transaction_summaries import TssV2TransactionsPost201ResponseEmbeddedTransactionSummaries
from .tss_v2_transactions_post400_response import TssV2TransactionsPost400Response
from .ums_v1_users_get200_response import UmsV1UsersGet200Response
from .ums_v1_users_get200_response_account_information import UmsV1UsersGet200ResponseAccountInformation
from .ums_v1_users_get200_response_contact_information import UmsV1UsersGet200ResponseContactInformation
from .ums_v1_users_get200_response_organization_information import UmsV1UsersGet200ResponseOrganizationInformation
from .ums_v1_users_get200_response_users import UmsV1UsersGet200ResponseUsers
from .update_invoice_request import UpdateInvoiceRequest
from .v1_file_details_get200_response import V1FileDetailsGet200Response
from .v1_file_details_get200_response_file_details import V1FileDetailsGet200ResponseFileDetails
from .v1_file_details_get200_response__links import V1FileDetailsGet200ResponseLinks
from .v1_file_details_get200_response__links_files import V1FileDetailsGet200ResponseLinksFiles
from .v1_file_details_get200_response__links_self import V1FileDetailsGet200ResponseLinksSelf
from .validate_export_compliance_request import ValidateExportComplianceRequest
from .validate_request import ValidateRequest
from .vas_v2_payments_post201_response import VasV2PaymentsPost201Response
from .vas_v2_payments_post201_response__links import VasV2PaymentsPost201ResponseLinks
from .vas_v2_payments_post201_response_order_information import VasV2PaymentsPost201ResponseOrderInformation
from .vas_v2_payments_post201_response_order_information_jurisdiction import VasV2PaymentsPost201ResponseOrderInformationJurisdiction
from .vas_v2_payments_post201_response_order_information_line_items import VasV2PaymentsPost201ResponseOrderInformationLineItems
from .vas_v2_payments_post201_response_order_information_tax_details import VasV2PaymentsPost201ResponseOrderInformationTaxDetails
from .vas_v2_payments_post201_response_tax_information import VasV2PaymentsPost201ResponseTaxInformation
from .vas_v2_payments_post400_response import VasV2PaymentsPost400Response
from .vas_v2_tax_void200_response import VasV2TaxVoid200Response
from .vas_v2_tax_void200_response_void_amount_details import VasV2TaxVoid200ResponseVoidAmountDetails
from .vas_v2_tax_voids_post400_response import VasV2TaxVoidsPost400Response
from .vasv2tax_buyer_information import Vasv2taxBuyerInformation
from .vasv2tax_client_reference_information import Vasv2taxClientReferenceInformation
from .vasv2tax_client_reference_information_partner import Vasv2taxClientReferenceInformationPartner
from .vasv2tax_merchant_information import Vasv2taxMerchantInformation
from .vasv2tax_order_information import Vasv2taxOrderInformation
from .vasv2tax_order_information_bill_to import Vasv2taxOrderInformationBillTo
from .vasv2tax_order_information_invoice_details import Vasv2taxOrderInformationInvoiceDetails
from .vasv2tax_order_information_line_items import Vasv2taxOrderInformationLineItems
from .vasv2tax_order_information_order_acceptance import Vasv2taxOrderInformationOrderAcceptance
from .vasv2tax_order_information_order_origin import Vasv2taxOrderInformationOrderOrigin
from .vasv2tax_order_information_ship_to import Vasv2taxOrderInformationShipTo
from .vasv2tax_order_information_shipping_details import Vasv2taxOrderInformationShippingDetails
from .vasv2tax_tax_information import Vasv2taxTaxInformation
from .vasv2taxid_client_reference_information import Vasv2taxidClientReferenceInformation
from .vasv2taxid_client_reference_information_partner import Vasv2taxidClientReferenceInformationPartner
from .verify_customer_address_request import VerifyCustomerAddressRequest
from .void_capture_request import VoidCaptureRequest
from .void_credit_request import VoidCreditRequest
from .void_payment_request import VoidPaymentRequest
from .void_refund_request import VoidRefundRequest
from .void_tax_request import VoidTaxRequest



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsTravelInformationAutoRentalReturnAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'location_id': 'str',
        'location': 'str'
    }

    attribute_map = {
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'location_id': 'locationId',
        'location': 'location'
    }

    def __init__(self, city=None, state=None, country=None, location_id=None, location=None):
        """
        Ptsv2paymentsTravelInformationAutoRentalReturnAddress - a model defined in Swagger
        """

        self._city = None
        self._state = None
        self._country = None
        self._location_id = None
        self._location = None

        if city is not None:
          self.city = city
        if state is not None:
          self.state = state
        if country is not None:
          self.country = country
        if location_id is not None:
          self.location_id = location_id
        if location is not None:
          self.location = location

    @property
    def city(self):
        """
        Gets the city of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        City where the auto was returned to the rental agency. 

        :return: The city of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        City where the auto was returned to the rental agency. 

        :param city: The city of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :type: str
        """
        if city is not None and len(city) > 25:
            raise ValueError("Invalid value for `city`, length must be less than or equal to `25`")

        self._city = city

    @property
    def state(self):
        """
        Gets the state of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        State in which the auto was returned to the rental agency. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  For authorizations, this field is supported for Visa, MasterCard, and American Express.  For captures, this field is supported only for MasterCard and American Express. 

        :return: The state of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        State in which the auto was returned to the rental agency. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  For authorizations, this field is supported for Visa, MasterCard, and American Express.  For captures, this field is supported only for MasterCard and American Express. 

        :param state: The state of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :type: str
        """
        if state is not None and len(state) > 3:
            raise ValueError("Invalid value for `state`, length must be less than or equal to `3`")

        self._state = state

    @property
    def country(self):
        """
        Gets the country of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        Country where the auto was returned to the rental agency. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). 

        :return: The country of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        Country where the auto was returned to the rental agency. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). 

        :param country: The country of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :type: str
        """
        if country is not None and len(country) > 3:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `3`")

        self._country = country

    @property
    def location_id(self):
        """
        Gets the location_id of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        Code, address, phone number, etc. used to identify the location of the auto rental return. This field is supported only for MasterCard and American Express. 

        :return: The location_id of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """
        Sets the location_id of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        Code, address, phone number, etc. used to identify the location of the auto rental return. This field is supported only for MasterCard and American Express. 

        :param location_id: The location_id of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :type: str
        """
        if location_id is not None and len(location_id) > 10:
            raise ValueError("Invalid value for `location_id`, length must be less than or equal to `10`")

        self._location_id = location_id

    @property
    def location(self):
        """
        Gets the location of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        This field contains the location where the taxi passenger was dropped off or where the auto rental vehicle was returned. 

        :return: The location of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        This field contains the location where the taxi passenger was dropped off or where the auto rental vehicle was returned. 

        :param location: The location of this Ptsv2paymentsTravelInformationAutoRentalReturnAddress.
        :type: str
        """
        if location is not None and len(location) > 38:
            raise ValueError("Invalid value for `location`, length must be less than or equal to `38`")

        self._location = location

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsTravelInformationAutoRentalReturnAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class ReportsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
	
    def __init__(self, merchant_config, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client
        self.api_client.set_configuration(merchant_config) 


    def create_report(self, create_adhoc_report_request, **kwargs):
        """
        Create Adhoc Report
        Create a one-time report. You must specify the type of report in reportDefinitionName. For a list of values for reportDefinitionName, see the [Reporting Developer Guide](https://www.cybersource.com/developers/documentation/reporting_and_reconciliation) 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_report(create_adhoc_report_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateAdhocReportRequest create_adhoc_report_request: Report subscription request payload (required)
        :param str organization_id: Valid Cybersource Organization Id
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_report_with_http_info(create_adhoc_report_request, **kwargs)
        else:
            (data) = self.create_report_with_http_info(create_adhoc_report_request, **kwargs)
            return data

    def create_report_with_http_info(self, create_adhoc_report_request, **kwargs):
        """
        Create Adhoc Report
        Create a one-time report. You must specify the type of report in reportDefinitionName. For a list of values for reportDefinitionName, see the [Reporting Developer Guide](https://www.cybersource.com/developers/documentation/reporting_and_reconciliation) 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_report_with_http_info(create_adhoc_report_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateAdhocReportRequest create_adhoc_report_request: Report subscription request payload (required)
        :param str organization_id: Valid Cybersource Organization Id
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_adhoc_report_request', 'organization_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_adhoc_report_request' is set
        if ('create_adhoc_report_request' not in params) or (params['create_adhoc_report_request'] is None):
            raise ValueError("Missing the required parameter `create_adhoc_report_request` when calling `create_report`")

        if 'organization_id' in params and len(params['organization_id']) > 32:
            raise ValueError("Invalid value for parameter `organization_id` when calling `create_report`, length must be less than or equal to `32`")
        if 'organization_id' in params and len(params['organization_id']) < 1:
            raise ValueError("Invalid value for parameter `organization_id` when calling `create_report`, length must be greater than or equal to `1`")
        if 'organization_id' in params and not re.search('[a-zA-Z0-9-_]+', params['organization_id']):
            raise ValueError("Invalid value for parameter `organization_id` when calling `create_report`, must conform to the pattern `/[a-zA-Z0-9-_]+/`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'organization_id' in params:
            query_params.append(('organizationId', params['organization_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_adhoc_report_request' in params:
            body_params = params['create_adhoc_report_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/reporting/v3/reports', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_report_by_report_id(self, report_id, **kwargs):
        """
        Get Report Based on Report Id
        Download a report using the reportId value. If you don’t already know this value, you can obtain it using the Retrieve available reports call. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_report_by_report_id(report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str report_id: Valid Report Id (required)
        :param str organization_id: Valid Cybersource Organization Id
        :return: ReportingV3ReportsIdGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_report_by_report_id_with_http_info(report_id, **kwargs)
        else:
            (data) = self.get_report_by_report_id_with_http_info(report_id, **kwargs)
            return data

    def get_report_by_report_id_with_http_info(self, report_id, **kwargs):
        """
        Get Report Based on Report Id
        Download a report using the reportId value. If you don’t already know this value, you can obtain it using the Retrieve available reports call. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_report_by_report_id_with_http_info(report_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str report_id: Valid Report Id (required)
        :param str organization_id: Valid Cybersource Organization Id
        :return: ReportingV3ReportsIdGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['report_id', 'organization_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_by_report_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'report_id' is set
        if ('report_id' not in params) or (params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `get_report_by_report_id`")

        if 'organization_id' in params and len(params['organization_id']) > 32:
            raise ValueError("Invalid value for parameter `organization_id` when calling `get_report_by_report_id`, length must be less than or equal to `32`")
        if 'organization_id' in params and len(params['organization_id']) < 1:
            raise ValueError("Invalid value for parameter `organization_id` when calling `get_report_by_report_id`, length must be greater than or equal to `1`")
        if 'organization_id' in params and not re.search('[a-zA-Z0-9-_]+', params['organization_id']):
            raise ValueError("Invalid value for parameter `organization_id` when calling `get_report_by_report_id`, must conform to the pattern `/[a-zA-Z0-9-_]+/`")

        collection_formats = {}

        path_params = {}
        if 'report_id' in params:
            path_params['reportId'] = params['report_id']

        query_params = []
        if 'organization_id' in params:
            query_params.append(('organizationId', params['organization_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json', 'application/xml'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/reporting/v3/reports/{report_id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='ReportingV3ReportsIdGet200Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def search_reports(self, start_time, end_time, time_query_type, **kwargs):
        """
        Retrieve Available Reports
        Retrieve a list of the available reports to which you are subscribed. This will also give you the reportId value, which you can also use to download a report. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.search_reports(start_time, end_time, time_query_type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param datetime start_time: Valid report Start Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)  **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZ (e.g. 2018-01-01T00:00:00.000Z)  (required)
        :param datetime end_time: Valid report End Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)  **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZ (e.g. 2018-01-01T00:00:00.000Z)  (required)
        :param str time_query_type: Specify time you would like to search  Valid values: - reportTimeFrame - executedTime  (required)
        :param str organization_id: Valid Cybersource Organization Id
        :param str report_mime_type: Valid Report Format  Valid values: - application/xml - text/csv 
        :param str report_frequency: Valid Report Frequency  Valid values: - DAILY - WEEKLY - MONTHLY - USER_DEFINED - ADHOC 
        :param str report_name: Valid Report Name
        :param int report_definition_id: Valid Report Definition Id
        :param str report_status: Valid Report Status  Valid values: - COMPLETED - PENDING - QUEUED - RUNNING - ERROR - NO_DATA 
        :return: ReportingV3ReportsGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.search_reports_with_http_info(start_time, end_time, time_query_type, **kwargs)
        else:
            (data) = self.search_reports_with_http_info(start_time, end_time, time_query_type, **kwargs)
            return data

    def search_reports_with_http_info(self, start_time, end_time, time_query_type, **kwargs):
        """
        Retrieve Available Reports
        Retrieve a list of the available reports to which you are subscribed. This will also give you the reportId value, which you can also use to download a report. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.search_reports_with_http_info(start_time, end_time, time_query_type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param datetime start_time: Valid report Start Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)  **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZ (e.g. 2018-01-01T00:00:00.000Z)  (required)
        :param datetime end_time: Valid report End Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)  **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZ (e.g. 2018-01-01T00:00:00.000Z)  (required)
        :param str time_query_type: Specify time you would like to search  Valid values: - reportTimeFrame - executedTime  (required)
        :param str organization_id: Valid Cybersource Organization Id
        :param str report_mime_type: Valid Report Format  Valid values: - application/xml - text/csv 
        :param str report_frequency: Valid Report Frequency  Valid values: - DAILY - WEEKLY - MONTHLY - USER_DEFINED - ADHOC 
        :param str report_name: Valid Report Name
        :param int report_definition_id: Valid Report Definition Id
        :param str report_status: Valid Report Status  Valid values: - COMPLETED - PENDING - QUEUED - RUNNING - ERROR - NO_DATA 
        :return: ReportingV3ReportsGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_query_type', 'organization_id', 'report_mime_type', 'report_frequency', 'report_name', 'report_definition_id', 'report_status']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_reports" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_time' is set
        if ('start_time' not in params) or (params['start_time'] is None):
            raise ValueError("Missing the required parameter `start_time` when calling `search_reports`")
        # verify the required parameter 'end_time' is set
        if ('end_time' not in params) or (params['end_time'] is None):
            raise ValueError("Missing the required parameter `end_time` when calling `search_reports`")
        # verify the required parameter 'time_query_type' is set
        if ('time_query_type' not in params) or (params['time_query_type'] is None):
            raise ValueError("Missing the required parameter `time_query_type` when calling `search_reports`")

        if 'organization_id' in params and len(params['organization_id']) > 32:
            raise ValueError("Invalid value for parameter `organization_id` when calling `search_reports`, length must be less than or equal to `32`")
        if 'organization_id' in params and len(params['organization_id']) < 1:
            raise ValueError("Invalid value for parameter `organization_id` when calling `search_reports`, length must be greater than or equal to `1`")
        if 'organization_id' in params and not re.search('[a-zA-Z0-9-_]+', params['organization_id']):
            raise ValueError("Invalid value for parameter `organization_id` when calling `search_reports`, must conform to the pattern `/[a-zA-Z0-9-_]+/`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'organization_id' in params:
            query_params.append(('organizationId', params['organization_id']))
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))
        if 'time_query_type' in params:
            query_params.append(('timeQueryType', params['time_query_type']))
        if 'report_mime_type' in params:
            query_params.append(('reportMimeType', params['report_mime_type']))
        if 'report_frequency' in params:
            query_params.append(('reportFrequency', params['report_frequency']))
        if 'report_name' in params:
            query_params.append(('reportName', params['report_name']))
        if 'report_definition_id' in params:
            query_params.append(('reportDefinitionId', params['report_definition_id']))
        if 'report_status' in params:
            query_params.append(('reportStatus', params['report_status']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/reporting/v3/reports', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='ReportingV3ReportsGet200Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'status': 'str',
        'settlement_time': 'datetime',
        'reason_code': 'str',
        'error_text': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'status': 'status',
        'settlement_time': 'settlementTime',
        'reason_code': 'reasonCode',
        'error_text': 'errorText'
    }

    def __init__(self, request_id=None, status=None, settlement_time=None, reason_code=None, error_text=None):
        """
        ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses - a model defined in Swagger
        """

        self._request_id = None
        self._status = None
        self._settlement_time = None
        self._reason_code = None
        self._error_text = None

        if request_id is not None:
          self.request_id = request_id
        if status is not None:
          self.status = status
        if settlement_time is not None:
          self.settlement_time = settlement_time
        if reason_code is not None:
          self.reason_code = reason_code
        if error_text is not None:
          self.error_text = error_text

    @property
    def request_id(self):
        """
        Gets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :return: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :param request_id: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :type: str
        """
        if request_id is not None and len(request_id) > 26:
            raise ValueError("Invalid value for `request_id`, length must be less than or equal to `26`")

        self._request_id = request_id

    @property
    def status(self):
        """
        Gets the status of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        Settlement Status

        :return: The status of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        Settlement Status

        :param status: The status of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :type: str
        """

        self._status = status

    @property
    def settlement_time(self):
        """
        Gets the settlement_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        Settlement Date

        :return: The settlement_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :rtype: datetime
        """
        return self._settlement_time

    @settlement_time.setter
    def settlement_time(self, settlement_time):
        """
        Sets the settlement_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        Settlement Date

        :param settlement_time: The settlement_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :type: datetime
        """

        self._settlement_time = settlement_time

    @property
    def reason_code(self):
        """
        Gets the reason_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        ReasonCode

        :return: The reason_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :rtype: str
        """
        return self._reason_code

    @reason_code.setter
    def reason_code(self, reason_code):
        """
        Sets the reason_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        ReasonCode

        :param reason_code: The reason_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :type: str
        """

        self._reason_code = reason_code

    @property
    def error_text(self):
        """
        Gets the error_text of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        errorText

        :return: The error_text of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :rtype: str
        """
        return self._error_text

    @error_text.setter
    def error_text(self, error_text):
        """
        Sets the error_text of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        errorText

        :param error_text: The error_text of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses.
        :type: str
        """

        self._error_text = error_text

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1decisionsClientReferenceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'comments': 'str'
    }

    attribute_map = {
        'code': 'code',
        'comments': 'comments'
    }

    def __init__(self, code=None, comments=None):
        """
        Riskv1decisionsClientReferenceInformation - a model defined in Swagger
        """

        self._code = None
        self._comments = None

        if code is not None:
          self.code = code
        if comments is not None:
          self.comments = comments

    @property
    def code(self):
        """
        Gets the code of this Riskv1decisionsClientReferenceInformation.
        Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.  #### Used by **Authorization** Required field.  #### PIN Debit Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed.  Required field for all PIN Debit requests (purchase, credit, and reversal).  #### FDC Nashville Global Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports. 

        :return: The code of this Riskv1decisionsClientReferenceInformation.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this Riskv1decisionsClientReferenceInformation.
        Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.  #### Used by **Authorization** Required field.  #### PIN Debit Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed.  Required field for all PIN Debit requests (purchase, credit, and reversal).  #### FDC Nashville Global Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports. 

        :param code: The code of this Riskv1decisionsClientReferenceInformation.
        :type: str
        """
        if code is not None and len(code) > 50:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `50`")

        self._code = code

    @property
    def comments(self):
        """
        Gets the comments of this Riskv1decisionsClientReferenceInformation.
        Brief description of the order or any comment you wish to add to the order. 

        :return: The comments of this Riskv1decisionsClientReferenceInformation.
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this Riskv1decisionsClientReferenceInformation.
        Brief description of the order or any comment you wish to add to the order. 

        :param comments: The comments of this Riskv1decisionsClientReferenceInformation.
        :type: str
        """
        if comments is not None and len(comments) > 255:
            raise ValueError("Invalid value for `comments`, length must be less than or equal to `255`")

        self._comments = comments

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1decisionsClientReferenceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200ResponseOthers(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'merchant_data1': 'str',
        'merchant_data2': 'str',
        'merchant_data3': 'str',
        'merchant_data4': 'str',
        'first_name': 'str',
        'last_name': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'merchant_data1': 'merchantData1',
        'merchant_data2': 'merchantData2',
        'merchant_data3': 'merchantData3',
        'merchant_data4': 'merchantData4',
        'first_name': 'firstName',
        'last_name': 'lastName'
    }

    def __init__(self, request_id=None, merchant_data1=None, merchant_data2=None, merchant_data3=None, merchant_data4=None, first_name=None, last_name=None):
        """
        ReportingV3PurchaseRefundDetailsGet200ResponseOthers - a model defined in Swagger
        """

        self._request_id = None
        self._merchant_data1 = None
        self._merchant_data2 = None
        self._merchant_data3 = None
        self._merchant_data4 = None
        self._first_name = None
        self._last_name = None

        if request_id is not None:
          self.request_id = request_id
        if merchant_data1 is not None:
          self.merchant_data1 = merchant_data1
        if merchant_data2 is not None:
          self.merchant_data2 = merchant_data2
        if merchant_data3 is not None:
          self.merchant_data3 = merchant_data3
        if merchant_data4 is not None:
          self.merchant_data4 = merchant_data4
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name

    @property
    def request_id(self):
        """
        Gets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :return: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :param request_id: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """
        if request_id is not None and len(request_id) > 26:
            raise ValueError("Invalid value for `request_id`, length must be less than or equal to `26`")

        self._request_id = request_id

    @property
    def merchant_data1(self):
        """
        Gets the merchant_data1 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :return: The merchant_data1 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._merchant_data1

    @merchant_data1.setter
    def merchant_data1(self, merchant_data1):
        """
        Sets the merchant_data1 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :param merchant_data1: The merchant_data1 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """

        self._merchant_data1 = merchant_data1

    @property
    def merchant_data2(self):
        """
        Gets the merchant_data2 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :return: The merchant_data2 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._merchant_data2

    @merchant_data2.setter
    def merchant_data2(self, merchant_data2):
        """
        Sets the merchant_data2 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :param merchant_data2: The merchant_data2 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """

        self._merchant_data2 = merchant_data2

    @property
    def merchant_data3(self):
        """
        Gets the merchant_data3 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :return: The merchant_data3 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._merchant_data3

    @merchant_data3.setter
    def merchant_data3(self, merchant_data3):
        """
        Sets the merchant_data3 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :param merchant_data3: The merchant_data3 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """

        self._merchant_data3 = merchant_data3

    @property
    def merchant_data4(self):
        """
        Gets the merchant_data4 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :return: The merchant_data4 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._merchant_data4

    @merchant_data4.setter
    def merchant_data4(self, merchant_data4):
        """
        Sets the merchant_data4 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Merchant Defined Data

        :param merchant_data4: The merchant_data4 of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """

        self._merchant_data4 = merchant_data4

    @property
    def first_name(self):
        """
        Gets the first_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        First Name

        :return: The first_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        First Name

        :param first_name: The first_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Last Name

        :return: The last_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        Last Name

        :param last_name: The last_name of this ReportingV3PurchaseRefundDetailsGet200ResponseOthers.
        :type: str
        """

        self._last_name = last_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200ResponseOthers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
